:orphan:

Wishlist
========

Ideally, this should mirror the `issues`_ listed on the ``ramlfications`` `github`_ page.  Ideally.

* Features:
    * Add ability to "pluralize" and "singularize" parameters in resourceTypes and traits (see `Issue 3`_).
    * Parse ``<< parameters >>`` in Resource nodes (see `Issue 2`_).
    * Parse ``$ref`` in JSON schemas – currently being worked on (see `PR 19`_).
    * Construct RAML via Python objects then ``dump``/``dumps`` them to file/string output.

.. _`github`: https://github.com/spotify/ramlfications
.. _`issues`: https://github.com/spotify/ramlfications/issues
.. _`PR 19`: https://github.com/spotify/ramlfications/pull/19
.. _`Issue 2`: https://github.com/spotify/ramlfications/issues/2
.. _`Issue 3`: https://github.com/spotify/ramlfications/issues/3
